@@ -3,7 +3,8 @@ package PDK::Device::Base;
 # 使用 Moose 的 Role 功能
 use Moose::Role;
 use Carp;
-use open qw(:std :utf8);
+
+# use open qw(:std :utf8);
 
 # 导入 Expect 模块，用于实现交互式脚本的功能
 use Expect;
@@ -61,6 +62,7 @@ sub enPrompt {
 sub telnet {
   my ($self, %param) = @_;
   $param{proto} = "telnet";
+  croak("请正确提供登录设备的权限账户密码") unless $param{username} && $param{password};
   return $self->driver(%param);
 }
 
@@ -68,6 +70,7 @@ sub telnet {
 sub ssh {
   my ($self, %param) = @_;
   $param{proto} = "ssh";
+  croak("请正确提供登录设备的权限账户密码") unless $param{username} && $param{password};
   return $self->driver(%param);
 }
 
@@ -200,9 +203,6 @@ sub driver {
 
   # 从参数中获取主机名、用户名、密码和连接协议，使用对象属性中的默认连接协议
   my ($host, $username, $password, $proto) = @param{qw/host username password proto/};
-  $proto    //= $self->proto;
-  $username //= $self->username;
-  $password //= $self->password;
 
   # 创建网络设备对象，初始化会话并获取配置信息
   my $session = $self->new(host => $host, username => $username, password => $password, proto => $proto);
