@@ -4,7 +4,8 @@ use Moose;
 use Carp;
 use namespace::autoclean;
 use Expect;
-use open qw(:std :utf8);
+
+# use open qw(:std :utf8);
 
 # 使用 'PDK::Device::Base' 角色
 with 'PDK::Device::Base';
